==> finclear-ibroker-proto-0.0.6-sources.jar: io/fincleartech/protobuf/ibroker/corpact/IBrokerCorporateActionServiceGrpc.java <==
package io.fincleartech.protobuf.ibroker.corpact;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.22.1)",
    comments = "Source: fincleartech/ibroker/corpact.proto")
public final class IBrokerCorporateActionServiceGrpc {

  private IBrokerCorporateActionServiceGrpc() {}

  public static final String SERVICE_NAME = "fincleartech.ibroker.IBrokerCorporateActionService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest,
      io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse> getTakeoverAcceptMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "TakeoverAccept",
      requestType = io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest.class,
      responseType = io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest,
      io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse> getTakeoverAcceptMethod() {
    io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest, io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse> getTakeoverAcceptMethod;
    if ((getTakeoverAcceptMethod = IBrokerCorporateActionServiceGrpc.getTakeoverAcceptMethod) == null) {
      synchronized (IBrokerCorporateActionServiceGrpc.class) {
        if ((getTakeoverAcceptMethod = IBrokerCorporateActionServiceGrpc.getTakeoverAcceptMethod) == null) {
          IBrokerCorporateActionServiceGrpc.getTakeoverAcceptMethod = getTakeoverAcceptMethod = 
              io.grpc.MethodDescriptor.<io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest, io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "fincleartech.ibroker.IBrokerCorporateActionService", "TakeoverAccept"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new IBrokerCorporateActionServiceMethodDescriptorSupplier("TakeoverAccept"))
                  .build();
          }
        }
     }
     return getTakeoverAcceptMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static IBrokerCorporateActionServiceStub newStub(io.grpc.Channel channel) {
    return new IBrokerCorporateActionServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static IBrokerCorporateActionServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new IBrokerCorporateActionServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static IBrokerCorporateActionServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new IBrokerCorporateActionServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class IBrokerCorporateActionServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void takeoverAccept(io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest request,
        io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getTakeoverAcceptMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getTakeoverAcceptMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest,
                io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse>(
                  this, METHODID_TAKEOVER_ACCEPT)))
          .build();
    }
  }

  /**
   */
  public static final class IBrokerCorporateActionServiceStub extends io.grpc.stub.AbstractStub<IBrokerCorporateActionServiceStub> {
    private IBrokerCorporateActionServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerCorporateActionServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerCorporateActionServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerCorporateActionServiceStub(channel, callOptions);
    }

    /**
     */
    public void takeoverAccept(io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest request,
        io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getTakeoverAcceptMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class IBrokerCorporateActionServiceBlockingStub extends io.grpc.stub.AbstractStub<IBrokerCorporateActionServiceBlockingStub> {
    private IBrokerCorporateActionServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerCorporateActionServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerCorporateActionServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerCorporateActionServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse takeoverAccept(io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest request) {
      return blockingUnaryCall(
          getChannel(), getTakeoverAcceptMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class IBrokerCorporateActionServiceFutureStub extends io.grpc.stub.AbstractStub<IBrokerCorporateActionServiceFutureStub> {
    private IBrokerCorporateActionServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerCorporateActionServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerCorporateActionServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerCorporateActionServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse> takeoverAccept(
        io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest request) {
      return futureUnaryCall(
          getChannel().newCall(getTakeoverAcceptMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_TAKEOVER_ACCEPT = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final IBrokerCorporateActionServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(IBrokerCorporateActionServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_TAKEOVER_ACCEPT:
          serviceImpl.takeoverAccept((io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptRequest) request,
              (io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.corpact.TakeoverAcceptResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class IBrokerCorporateActionServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    IBrokerCorporateActionServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return io.fincleartech.protobuf.ibroker.corpact.Corpact.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("IBrokerCorporateActionService");
    }
  }

  private static final class IBrokerCorporateActionServiceFileDescriptorSupplier
      extends IBrokerCorporateActionServiceBaseDescriptorSupplier {
    IBrokerCorporateActionServiceFileDescriptorSupplier() {}
  }

  private static final class IBrokerCorporateActionServiceMethodDescriptorSupplier
      extends IBrokerCorporateActionServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    IBrokerCorporateActionServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (IBrokerCorporateActionServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new IBrokerCorporateActionServiceFileDescriptorSupplier())
              .addMethod(getTakeoverAcceptMethod())
              .build();
        }
      }
    }
    return result;
  }
}

==> finclear-ibroker-proto-0.1.5-sources.jar: io/fincleartech/protobuf/ibroker/corpact/IBrokerCorporateActionServiceGrpc.java <==
package io.fincleartech.protobuf.ibroker.corpact;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.22.1)",
    comments = "Source: fincleartech/ibroker/corpact.proto")
public final class IBrokerCorporateActionServiceGrpc {

  private IBrokerCorporateActionServiceGrpc() {}

  public static final String SERVICE_NAME = "fincleartech.ibroker.IBrokerCorporateActionService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest,
      io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse> getParticipantInitiatedBidElectionMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "ParticipantInitiatedBidElection",
      requestType = io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest.class,
      responseType = io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest,
      io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse> getParticipantInitiatedBidElectionMethod() {
    io.grpc.MethodDescriptor<io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest, io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse> getParticipantInitiatedBidElectionMethod;
    if ((getParticipantInitiatedBidElectionMethod = IBrokerCorporateActionServiceGrpc.getParticipantInitiatedBidElectionMethod) == null) {
      synchronized (IBrokerCorporateActionServiceGrpc.class) {
        if ((getParticipantInitiatedBidElectionMethod = IBrokerCorporateActionServiceGrpc.getParticipantInitiatedBidElectionMethod) == null) {
          IBrokerCorporateActionServiceGrpc.getParticipantInitiatedBidElectionMethod = getParticipantInitiatedBidElectionMethod = 
              io.grpc.MethodDescriptor.<io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest, io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "fincleartech.ibroker.IBrokerCorporateActionService", "ParticipantInitiatedBidElection"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse.getDefaultInstance()))
                  .setSchemaDescriptor(new IBrokerCorporateActionServiceMethodDescriptorSupplier("ParticipantInitiatedBidElection"))
                  .build();
          }
        }
     }
     return getParticipantInitiatedBidElectionMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static IBrokerCorporateActionServiceStub newStub(io.grpc.Channel channel) {
    return new IBrokerCorporateActionServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static IBrokerCorporateActionServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new IBrokerCorporateActionServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static IBrokerCorporateActionServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new IBrokerCorporateActionServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class IBrokerCorporateActionServiceImplBase implements io.grpc.BindableService {

    /**
     * <pre>
     * Acceptance of a corporate action election (takeover/buyback)
     * </pre>
     */
    public void participantInitiatedBidElection(io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest request,
        io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse> responseObserver) {
      asyncUnimplementedUnaryCall(getParticipantInitiatedBidElectionMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getParticipantInitiatedBidElectionMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest,
                io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse>(
                  this, METHODID_PARTICIPANT_INITIATED_BID_ELECTION)))
          .build();
    }
  }

  /**
   */
  public static final class IBrokerCorporateActionServiceStub extends io.grpc.stub.AbstractStub<IBrokerCorporateActionServiceStub> {
    private IBrokerCorporateActionServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerCorporateActionServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerCorporateActionServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerCorporateActionServiceStub(channel, callOptions);
    }

    /**
     * <pre>
     * Acceptance of a corporate action election (takeover/buyback)
     * </pre>
     */
    public void participantInitiatedBidElection(io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest request,
        io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getParticipantInitiatedBidElectionMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class IBrokerCorporateActionServiceBlockingStub extends io.grpc.stub.AbstractStub<IBrokerCorporateActionServiceBlockingStub> {
    private IBrokerCorporateActionServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerCorporateActionServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerCorporateActionServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerCorporateActionServiceBlockingStub(channel, callOptions);
    }

    /**
     * <pre>
     * Acceptance of a corporate action election (takeover/buyback)
     * </pre>
     */
    public io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse participantInitiatedBidElection(io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest request) {
      return blockingUnaryCall(
          getChannel(), getParticipantInitiatedBidElectionMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class IBrokerCorporateActionServiceFutureStub extends io.grpc.stub.AbstractStub<IBrokerCorporateActionServiceFutureStub> {
    private IBrokerCorporateActionServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private IBrokerCorporateActionServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected IBrokerCorporateActionServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new IBrokerCorporateActionServiceFutureStub(channel, callOptions);
    }

    /**
     * <pre>
     * Acceptance of a corporate action election (takeover/buyback)
     * </pre>
     */
    public com.google.common.util.concurrent.ListenableFuture<io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse> participantInitiatedBidElection(
        io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest request) {
      return futureUnaryCall(
          getChannel().newCall(getParticipantInitiatedBidElectionMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_PARTICIPANT_INITIATED_BID_ELECTION = 0;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final IBrokerCorporateActionServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(IBrokerCorporateActionServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_PARTICIPANT_INITIATED_BID_ELECTION:
          serviceImpl.participantInitiatedBidElection((io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionRequest) request,
              (io.grpc.stub.StreamObserver<io.fincleartech.protobuf.ibroker.corpact.ParticipantInitiatedBidElectionResponse>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class IBrokerCorporateActionServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    IBrokerCorporateActionServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return io.fincleartech.protobuf.ibroker.corpact.Corpact.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("IBrokerCorporateActionService");
    }
  }

  private static final class IBrokerCorporateActionServiceFileDescriptorSupplier
      extends IBrokerCorporateActionServiceBaseDescriptorSupplier {
    IBrokerCorporateActionServiceFileDescriptorSupplier() {}
  }

  private static final class IBrokerCorporateActionServiceMethodDescriptorSupplier
      extends IBrokerCorporateActionServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    IBrokerCorporateActionServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (IBrokerCorporateActionServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new IBrokerCorporateActionServiceFileDescriptorSupplier())
              .addMethod(getParticipantInitiatedBidElectionMethod())
              .build();
        }
      }
    }
    return result;
  }
}
